==> zio-aws-securityhub_2.13-5.17.124.2-sources.jar: zio/aws/securityhub/model/CreateFindingAggregatorResponse.scala <==
package zio.aws.securityhub.model
import zio.ZIO
import zio.aws.securityhub.model.primitives.NonEmptyString
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class CreateFindingAggregatorResponse(
    findingAggregatorArn: Option[NonEmptyString] = None,
    findingAggregationRegion: Option[NonEmptyString] = None,
    regionLinkingMode: Option[NonEmptyString] = None,
    regions: Option[Iterable[NonEmptyString]] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.securityhub.model.CreateFindingAggregatorResponse = {
    import CreateFindingAggregatorResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.securityhub.model.CreateFindingAggregatorResponse
      .builder()
      .optionallyWith(
        findingAggregatorArn.map(value =>
          NonEmptyString.unwrap(value): java.lang.String
        )
      )(_.findingAggregatorArn)
      .optionallyWith(
        findingAggregationRegion.map(value =>
          NonEmptyString.unwrap(value): java.lang.String
        )
      )(_.findingAggregationRegion)
      .optionallyWith(
        regionLinkingMode.map(value =>
          NonEmptyString.unwrap(value): java.lang.String
        )
      )(_.regionLinkingMode)
      .optionallyWith(
        regions.map(value =>
          value.map { item =>
            NonEmptyString.unwrap(item): java.lang.String
          }.asJavaCollection
        )
      )(_.regions)
      .build()
  }
  def asReadOnly
      : zio.aws.securityhub.model.CreateFindingAggregatorResponse.ReadOnly =
    zio.aws.securityhub.model.CreateFindingAggregatorResponse
      .wrap(buildAwsValue())
}
object CreateFindingAggregatorResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.securityhub.model.CreateFindingAggregatorResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.securityhub.model.CreateFindingAggregatorResponse =
      zio.aws.securityhub.model.CreateFindingAggregatorResponse(
        findingAggregatorArn.map(value => value),
        findingAggregationRegion.map(value => value),
        regionLinkingMode.map(value => value),
        regions.map(value => value)
      )
    def findingAggregatorArn: Option[NonEmptyString]
    def findingAggregationRegion: Option[NonEmptyString]
    def regionLinkingMode: Option[NonEmptyString]
    def regions: Option[List[NonEmptyString]]
    def getFindingAggregatorArn: ZIO[Any, AwsError, NonEmptyString] =
      AwsError.unwrapOptionField("findingAggregatorArn", findingAggregatorArn)
    def getFindingAggregationRegion: ZIO[Any, AwsError, NonEmptyString] =
      AwsError.unwrapOptionField(
        "findingAggregationRegion",
        findingAggregationRegion
      )
    def getRegionLinkingMode: ZIO[Any, AwsError, NonEmptyString] =
      AwsError.unwrapOptionField("regionLinkingMode", regionLinkingMode)
    def getRegions: ZIO[Any, AwsError, List[NonEmptyString]] =
      AwsError.unwrapOptionField("regions", regions)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.securityhub.model.CreateFindingAggregatorResponse
  ) extends zio.aws.securityhub.model.CreateFindingAggregatorResponse.ReadOnly {
    override val findingAggregatorArn: Option[NonEmptyString] = scala
      .Option(impl.findingAggregatorArn())
      .map(value => zio.aws.securityhub.model.primitives.NonEmptyString(value))
    override val findingAggregationRegion: Option[NonEmptyString] = scala
      .Option(impl.findingAggregationRegion())
      .map(value => zio.aws.securityhub.model.primitives.NonEmptyString(value))
    override val regionLinkingMode: Option[NonEmptyString] = scala
      .Option(impl.regionLinkingMode())
      .map(value => zio.aws.securityhub.model.primitives.NonEmptyString(value))
    override val regions: Option[List[NonEmptyString]] = scala
      .Option(impl.regions())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.securityhub.model.primitives.NonEmptyString(item)
        }.toList
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.securityhub.model.CreateFindingAggregatorResponse
  ): zio.aws.securityhub.model.CreateFindingAggregatorResponse.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-securityhub_2.13-7.21.15.1-sources.jar: zio/aws/securityhub/model/CreateFindingAggregatorResponse.scala <==
package zio.aws.securityhub.model
import zio.ZIO
import zio.aws.securityhub.model.primitives.NonEmptyString
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class CreateFindingAggregatorResponse(
    findingAggregatorArn: Optional[NonEmptyString] = Optional.Absent,
    findingAggregationRegion: Optional[NonEmptyString] = Optional.Absent,
    regionLinkingMode: Optional[NonEmptyString] = Optional.Absent,
    regions: Optional[Iterable[NonEmptyString]] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.securityhub.model.CreateFindingAggregatorResponse = {
    import CreateFindingAggregatorResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.securityhub.model.CreateFindingAggregatorResponse
      .builder()
      .optionallyWith(
        findingAggregatorArn.map(value =>
          NonEmptyString.unwrap(value): java.lang.String
        )
      )(_.findingAggregatorArn)
      .optionallyWith(
        findingAggregationRegion.map(value =>
          NonEmptyString.unwrap(value): java.lang.String
        )
      )(_.findingAggregationRegion)
      .optionallyWith(
        regionLinkingMode.map(value =>
          NonEmptyString.unwrap(value): java.lang.String
        )
      )(_.regionLinkingMode)
      .optionallyWith(
        regions.map(value =>
          value.map { item =>
            NonEmptyString.unwrap(item): java.lang.String
          }.asJavaCollection
        )
      )(_.regions)
      .build()
  }
  def asReadOnly
      : zio.aws.securityhub.model.CreateFindingAggregatorResponse.ReadOnly =
    zio.aws.securityhub.model.CreateFindingAggregatorResponse
      .wrap(buildAwsValue())
}
object CreateFindingAggregatorResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.securityhub.model.CreateFindingAggregatorResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.securityhub.model.CreateFindingAggregatorResponse =
      zio.aws.securityhub.model.CreateFindingAggregatorResponse(
        findingAggregatorArn.map(value => value),
        findingAggregationRegion.map(value => value),
        regionLinkingMode.map(value => value),
        regions.map(value => value)
      )
    def findingAggregatorArn: Optional[NonEmptyString]
    def findingAggregationRegion: Optional[NonEmptyString]
    def regionLinkingMode: Optional[NonEmptyString]
    def regions: Optional[List[NonEmptyString]]
    def getFindingAggregatorArn: ZIO[Any, AwsError, NonEmptyString] =
      AwsError.unwrapOptionField("findingAggregatorArn", findingAggregatorArn)
    def getFindingAggregationRegion: ZIO[Any, AwsError, NonEmptyString] =
      AwsError.unwrapOptionField(
        "findingAggregationRegion",
        findingAggregationRegion
      )
    def getRegionLinkingMode: ZIO[Any, AwsError, NonEmptyString] =
      AwsError.unwrapOptionField("regionLinkingMode", regionLinkingMode)
    def getRegions: ZIO[Any, AwsError, List[NonEmptyString]] =
      AwsError.unwrapOptionField("regions", regions)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.securityhub.model.CreateFindingAggregatorResponse
  ) extends zio.aws.securityhub.model.CreateFindingAggregatorResponse.ReadOnly {
    override val findingAggregatorArn: Optional[NonEmptyString] =
      zio.aws.core.internal
        .optionalFromNullable(impl.findingAggregatorArn())
        .map(value =>
          zio.aws.securityhub.model.primitives.NonEmptyString(value)
        )
    override val findingAggregationRegion: Optional[NonEmptyString] =
      zio.aws.core.internal
        .optionalFromNullable(impl.findingAggregationRegion())
        .map(value =>
          zio.aws.securityhub.model.primitives.NonEmptyString(value)
        )
    override val regionLinkingMode: Optional[NonEmptyString] =
      zio.aws.core.internal
        .optionalFromNullable(impl.regionLinkingMode())
        .map(value =>
          zio.aws.securityhub.model.primitives.NonEmptyString(value)
        )
    override val regions: Optional[List[NonEmptyString]] = zio.aws.core.internal
      .optionalFromNullable(impl.regions())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.securityhub.model.primitives.NonEmptyString(item)
        }.toList
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.securityhub.model.CreateFindingAggregatorResponse
  ): zio.aws.securityhub.model.CreateFindingAggregatorResponse.ReadOnly =
    new Wrapper(impl)
}
